@@ -28,6 +28,8 @@ from histogrammar.dfinterface.make_histograms import (
 # pandas/spark dataframe decorators
 from popmon import decorators
 
+from .config import Settings
+from .extensions import extensions
 from .pipeline.metrics import df_stability_metrics, stability_metrics
 from .pipeline.report import df_stability_report, stability_report
 from .stitching import stitch_histograms
@@ -44,4 +46,6 @@ __all__ = [
     "stability_report",
     "stitch_histograms",
     "__version__",
+    "Settings",
+    "extensions",
 ]
