@@ -16,8 +16,6 @@
 # COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 # IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 # CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-
-
 from ...analysis.comparison.hist_comparer import (
     ExpandingHistComparer,
     ExpandingNormHistComparer,
@@ -26,8 +24,10 @@ from ...analysis.comparison.hist_comparer import (
     RollingHistComparer,
     RollingNormHistComparer,
 )
+from .comparisons import Comparisons
 
 __all__ = [
+    "Comparisons",
     "ReferenceHistComparer",
     "RollingHistComparer",
     "ExpandingHistComparer",
