@@ -19,7 +19,7 @@
 
 
 # Resources lookup file for popmon
-
+import json
 import pathlib
 
 from jinja2 import Environment, FileSystemLoader
@@ -53,6 +53,31 @@ _TEMPLATES_ENV = Environment(
 _TEMPLATES_ENV.filters["fmt_metric"] = lambda x: x.replace("_", " ")
 
 
+def _js_list(encoder, data):
+    pairs = [_js_val(encoder, v) for v in data]
+    return "[" + ", ".join(pairs) + "]"
+
+
+def _js_dict(encoder, data):
+    pairs = [k + ": " + _js_val(encoder, v) for k, v in data.items()]
+    return "{" + ", ".join(pairs) + "}"
+
+
+def _js_val(encoder, data):
+    if isinstance(data, dict):
+        val = _js_dict(encoder, data)
+    elif isinstance(data, list):
+        val = _js_list(encoder, data)
+    else:
+        val = encoder.encode(data)
+    return val
+
+
+_TEMPLATES_ENV.filters["json_plot"] = lambda x: _js_val(
+    json.JSONEncoder(ensure_ascii=False), x
+)
+
+
 def _resource(resource_type, name: str) -> str:
     """Return the full path filename of a resource.
 
